@@ -349,7 +349,7 @@ public:
     /**
      * Iterator type for \c NiftiImageData, with \c Element as its value type
     **/
-    class Iterator : public std::iterator<std::random_access_iterator_tag, Element>
+    class Iterator
     {
     private:
         const NiftiImageData &parent;
@@ -357,6 +357,13 @@ public:
         size_t step;
         
     public:
+        // Standard iterator typedefs
+        typedef std::random_access_iterator_tag iterator_category;
+        typedef Element value_type;
+        typedef std::ptrdiff_t difference_type;
+        typedef Element* pointer;
+        typedef Element& reference;
+        
         /**
          * Primary constructor
          * @param parent A reference to the parent object
@@ -887,7 +894,7 @@ public:
             for (int i=1; i<dimension; i++)
                 blockSize *= image->dim[i];
             
-            if (blockSize != source->nvox)
+            if (blockSize != size_t(source->nvox))
                 throw std::runtime_error("New data does not have the same size as the target block");
             
             blockSize *= image->nbyper;
@@ -1171,6 +1178,17 @@ public:
             return *this;
         }
         
+#ifdef USING_R
+        /**
+         * Copy assignment operator, taking a \c SEXP and replacing linked data
+        **/
+        Xform & operator= (SEXP source)
+        {
+            replace(Matrix(source));
+            return *this;
+        }
+#endif
+        
         /**
          * Access the xform matrix as an immutable \c SquareMatrix object
         **/
